function varargout=slice(Th,u,P,varargin)
% FUNCTION slice
%   Plots scalar data values on the intersection of the plane defined by
%         P(1)*x+P(2)*y+P(3)*z+P(4)=0
%   and the siMesh object.
%
% USAGE
%   fc_siplt.slice(Th,u,P) or slice(Th,u,P) where 
%     Th is a siMesh object,
%     u  is the data values on Th vertices, Th.nq-by-1 array,
%     P  is a vector which contains the coefficients of the plane.
%
%   fc_siplt.slice(Th,u,P,key,value,...) allows additional key/value pairs to be 
%     used when displaying the siMesh object. The key strings could be
%
%     'labels' to specify the labels of the elementary meshes. 
%              Default [] i.e all.
%
% SAMPLES
%   Th=fc_simesh.HyperCube(3,10);
%   U=Th.eval(@(x,y,z) cos(2*x-y+z).*sin(x+y-3*z));
%   P=fc_tools.graphics.PlaneCoefs(0.5*[1 1 1],[1 -1 1]);
%   figure(1)
%   fc_siplt.slice(Th,U,P)
%   hold on
%   fc_siplt.plot(Th,'d',1,'color','k')
%
%    Copyright (C) 2017-2010 F. Cuvelier
  assert(fc_simesh.is_siMesh(Th))
  assert(Th.d==3 && Th.dim==3);
  U=Th.eval(u); % also verifies dimensions...
  p = inputParser; 
  p.KeepUnmatched=true; 
  p.addParamValue('labels',[]); % select labels to draw
  p.addParamValue('merge',true,@islogical);
  p.parse(varargin{:});
  R=p.Results;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  
  if isempty(R.labels), idxlab=Th.find(3);else idxlab=Th.find(3,R.labels);end
  if isempty(idxlab), return;end
  hfig=gcf();
  PrevHold=fc_tools.graphics.SetHoldOn(true);
  if ~PrevHold, clf;hold on;end
  if R.merge
    [q,me,toGlobal]=Th.get_mesh('labels',R.labels);
    fc_graphics4mesh.slice(q,me,U(toGlobal),P,varargin{:});
  else
    for ilab=[idxlab]
      sTh=Th.sTh{ilab};
      fc_graphics4mesh.slice(sTh.q,sTh.me,sTh.getLocalData(U),P,varargin{:});
    end
  end
  fc_tools.graphics.RestoreHold(PrevHold)
  figure(hfig);
end
